# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `LogicalChannel.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Length' not in _M_omero.model.__dict__:
    _M_omero.model._t_Length = IcePy.declareClass('::omero::model::Length')
    _M_omero.model._t_LengthPrx = IcePy.declareProxy('::omero::model::Length')

if 'Illumination' not in _M_omero.model.__dict__:
    _M_omero.model._t_Illumination = IcePy.declareClass('::omero::model::Illumination')
    _M_omero.model._t_IlluminationPrx = IcePy.declareProxy('::omero::model::Illumination')

if 'ContrastMethod' not in _M_omero.model.__dict__:
    _M_omero.model._t_ContrastMethod = IcePy.declareClass('::omero::model::ContrastMethod')
    _M_omero.model._t_ContrastMethodPrx = IcePy.declareProxy('::omero::model::ContrastMethod')

if 'OTF' not in _M_omero.model.__dict__:
    _M_omero.model._t_OTF = IcePy.declareClass('::omero::model::OTF')
    _M_omero.model._t_OTFPrx = IcePy.declareProxy('::omero::model::OTF')

if 'DetectorSettings' not in _M_omero.model.__dict__:
    _M_omero.model._t_DetectorSettings = IcePy.declareClass('::omero::model::DetectorSettings')
    _M_omero.model._t_DetectorSettingsPrx = IcePy.declareProxy('::omero::model::DetectorSettings')

if 'LightSettings' not in _M_omero.model.__dict__:
    _M_omero.model._t_LightSettings = IcePy.declareClass('::omero::model::LightSettings')
    _M_omero.model._t_LightSettingsPrx = IcePy.declareProxy('::omero::model::LightSettings')

if 'FilterSet' not in _M_omero.model.__dict__:
    _M_omero.model._t_FilterSet = IcePy.declareClass('::omero::model::FilterSet')
    _M_omero.model._t_FilterSetPrx = IcePy.declareProxy('::omero::model::FilterSet')

if 'PhotometricInterpretation' not in _M_omero.model.__dict__:
    _M_omero.model._t_PhotometricInterpretation = IcePy.declareClass('::omero::model::PhotometricInterpretation')
    _M_omero.model._t_PhotometricInterpretationPrx = IcePy.declareProxy('::omero::model::PhotometricInterpretation')

if 'AcquisitionMode' not in _M_omero.model.__dict__:
    _M_omero.model._t_AcquisitionMode = IcePy.declareClass('::omero::model::AcquisitionMode')
    _M_omero.model._t_AcquisitionModePrx = IcePy.declareProxy('::omero::model::AcquisitionMode')

if 'Channel' not in _M_omero.model.__dict__:
    _M_omero.model._t_Channel = IcePy.declareClass('::omero::model::Channel')
    _M_omero.model._t_ChannelPrx = IcePy.declareProxy('::omero::model::Channel')

if 'LightPath' not in _M_omero.model.__dict__:
    _M_omero.model._t_LightPath = IcePy.declareClass('::omero::model::LightPath')
    _M_omero.model._t_LightPathPrx = IcePy.declareProxy('::omero::model::LightPath')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_LogicalChannelChannelsSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_LogicalChannelChannelsSeq = IcePy.defineSequence('::omero::model::LogicalChannelChannelsSeq', (), _M_omero.model._t_Channel)

if 'LogicalChannel' not in _M_omero.model.__dict__:
    _M_omero.model.LogicalChannel = Ice.createTempClass()
    class LogicalChannel(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _name=None, _pinHoleSize=None, _illumination=None, _contrastMethod=None, _excitationWave=None, _emissionWave=None, _fluor=None, _ndFilter=None, _otf=None, _detectorSettings=None, _lightSourceSettings=None, _filterSet=None, _samplesPerPixel=None, _photometricInterpretation=None, _mode=None, _pockelCellSetting=None, _channelsSeq=None, _channelsLoaded=False, _lightPath=None):
            if Ice.getType(self) == _M_omero.model.LogicalChannel:
                raise RuntimeError('omero.model.LogicalChannel is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._name = _name
            self._pinHoleSize = _pinHoleSize
            self._illumination = _illumination
            self._contrastMethod = _contrastMethod
            self._excitationWave = _excitationWave
            self._emissionWave = _emissionWave
            self._fluor = _fluor
            self._ndFilter = _ndFilter
            self._otf = _otf
            self._detectorSettings = _detectorSettings
            self._lightSourceSettings = _lightSourceSettings
            self._filterSet = _filterSet
            self._samplesPerPixel = _samplesPerPixel
            self._photometricInterpretation = _photometricInterpretation
            self._mode = _mode
            self._pockelCellSetting = _pockelCellSetting
            self._channelsSeq = _channelsSeq
            self._channelsLoaded = _channelsLoaded
            self._lightPath = _lightPath

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::LogicalChannel')

        def ice_id(self, current=None):
            return '::omero::model::LogicalChannel'

        def ice_staticId():
            return '::omero::model::LogicalChannel'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getName(self, current=None):
            pass

        def setName(self, theName, current=None):
            pass

        def getPinHoleSize(self, current=None):
            pass

        def setPinHoleSize(self, thePinHoleSize, current=None):
            pass

        def getIllumination(self, current=None):
            pass

        def setIllumination(self, theIllumination, current=None):
            pass

        def getContrastMethod(self, current=None):
            pass

        def setContrastMethod(self, theContrastMethod, current=None):
            pass

        def getExcitationWave(self, current=None):
            pass

        def setExcitationWave(self, theExcitationWave, current=None):
            pass

        def getEmissionWave(self, current=None):
            pass

        def setEmissionWave(self, theEmissionWave, current=None):
            pass

        def getFluor(self, current=None):
            pass

        def setFluor(self, theFluor, current=None):
            pass

        def getNdFilter(self, current=None):
            pass

        def setNdFilter(self, theNdFilter, current=None):
            pass

        def getOtf(self, current=None):
            pass

        def setOtf(self, theOtf, current=None):
            pass

        def getDetectorSettings(self, current=None):
            pass

        def setDetectorSettings(self, theDetectorSettings, current=None):
            pass

        def getLightSourceSettings(self, current=None):
            pass

        def setLightSourceSettings(self, theLightSourceSettings, current=None):
            pass

        def getFilterSet(self, current=None):
            pass

        def setFilterSet(self, theFilterSet, current=None):
            pass

        def getSamplesPerPixel(self, current=None):
            pass

        def setSamplesPerPixel(self, theSamplesPerPixel, current=None):
            pass

        def getPhotometricInterpretation(self, current=None):
            pass

        def setPhotometricInterpretation(self, thePhotometricInterpretation, current=None):
            pass

        def getMode(self, current=None):
            pass

        def setMode(self, theMode, current=None):
            pass

        def getPockelCellSetting(self, current=None):
            pass

        def setPockelCellSetting(self, thePockelCellSetting, current=None):
            pass

        def unloadChannels(self, current=None):
            pass

        def sizeOfChannels(self, current=None):
            pass

        def copyChannels(self, current=None):
            pass

        def addChannel(self, target, current=None):
            pass

        def addAllChannelSet(self, targets, current=None):
            pass

        def removeChannel(self, theTarget, current=None):
            pass

        def removeAllChannelSet(self, targets, current=None):
            pass

        def clearChannels(self, current=None):
            pass

        def reloadChannels(self, toCopy, current=None):
            pass

        def getLightPath(self, current=None):
            pass

        def setLightPath(self, theLightPath, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_LogicalChannel)

        __repr__ = __str__

    _M_omero.model.LogicalChannelPrx = Ice.createTempClass()
    class LogicalChannelPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.LogicalChannel._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.LogicalChannel._op_setVersion.end(self, _r)

        def getName(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getName.invoke(self, ((), _ctx))

        def begin_getName(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getName.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getName(self, _r):
            return _M_omero.model.LogicalChannel._op_getName.end(self, _r)

        def setName(self, theName, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setName.invoke(self, ((theName, ), _ctx))

        def begin_setName(self, theName, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setName.begin(self, ((theName, ), _response, _ex, _sent, _ctx))

        def end_setName(self, _r):
            return _M_omero.model.LogicalChannel._op_setName.end(self, _r)

        def getPinHoleSize(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getPinHoleSize.invoke(self, ((), _ctx))

        def begin_getPinHoleSize(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getPinHoleSize.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPinHoleSize(self, _r):
            return _M_omero.model.LogicalChannel._op_getPinHoleSize.end(self, _r)

        def setPinHoleSize(self, thePinHoleSize, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setPinHoleSize.invoke(self, ((thePinHoleSize, ), _ctx))

        def begin_setPinHoleSize(self, thePinHoleSize, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setPinHoleSize.begin(self, ((thePinHoleSize, ), _response, _ex, _sent, _ctx))

        def end_setPinHoleSize(self, _r):
            return _M_omero.model.LogicalChannel._op_setPinHoleSize.end(self, _r)

        def getIllumination(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getIllumination.invoke(self, ((), _ctx))

        def begin_getIllumination(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getIllumination.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getIllumination(self, _r):
            return _M_omero.model.LogicalChannel._op_getIllumination.end(self, _r)

        def setIllumination(self, theIllumination, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setIllumination.invoke(self, ((theIllumination, ), _ctx))

        def begin_setIllumination(self, theIllumination, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setIllumination.begin(self, ((theIllumination, ), _response, _ex, _sent, _ctx))

        def end_setIllumination(self, _r):
            return _M_omero.model.LogicalChannel._op_setIllumination.end(self, _r)

        def getContrastMethod(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getContrastMethod.invoke(self, ((), _ctx))

        def begin_getContrastMethod(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getContrastMethod.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getContrastMethod(self, _r):
            return _M_omero.model.LogicalChannel._op_getContrastMethod.end(self, _r)

        def setContrastMethod(self, theContrastMethod, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setContrastMethod.invoke(self, ((theContrastMethod, ), _ctx))

        def begin_setContrastMethod(self, theContrastMethod, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setContrastMethod.begin(self, ((theContrastMethod, ), _response, _ex, _sent, _ctx))

        def end_setContrastMethod(self, _r):
            return _M_omero.model.LogicalChannel._op_setContrastMethod.end(self, _r)

        def getExcitationWave(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getExcitationWave.invoke(self, ((), _ctx))

        def begin_getExcitationWave(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getExcitationWave.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getExcitationWave(self, _r):
            return _M_omero.model.LogicalChannel._op_getExcitationWave.end(self, _r)

        def setExcitationWave(self, theExcitationWave, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setExcitationWave.invoke(self, ((theExcitationWave, ), _ctx))

        def begin_setExcitationWave(self, theExcitationWave, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setExcitationWave.begin(self, ((theExcitationWave, ), _response, _ex, _sent, _ctx))

        def end_setExcitationWave(self, _r):
            return _M_omero.model.LogicalChannel._op_setExcitationWave.end(self, _r)

        def getEmissionWave(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getEmissionWave.invoke(self, ((), _ctx))

        def begin_getEmissionWave(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getEmissionWave.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getEmissionWave(self, _r):
            return _M_omero.model.LogicalChannel._op_getEmissionWave.end(self, _r)

        def setEmissionWave(self, theEmissionWave, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setEmissionWave.invoke(self, ((theEmissionWave, ), _ctx))

        def begin_setEmissionWave(self, theEmissionWave, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setEmissionWave.begin(self, ((theEmissionWave, ), _response, _ex, _sent, _ctx))

        def end_setEmissionWave(self, _r):
            return _M_omero.model.LogicalChannel._op_setEmissionWave.end(self, _r)

        def getFluor(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getFluor.invoke(self, ((), _ctx))

        def begin_getFluor(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getFluor.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getFluor(self, _r):
            return _M_omero.model.LogicalChannel._op_getFluor.end(self, _r)

        def setFluor(self, theFluor, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setFluor.invoke(self, ((theFluor, ), _ctx))

        def begin_setFluor(self, theFluor, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setFluor.begin(self, ((theFluor, ), _response, _ex, _sent, _ctx))

        def end_setFluor(self, _r):
            return _M_omero.model.LogicalChannel._op_setFluor.end(self, _r)

        def getNdFilter(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getNdFilter.invoke(self, ((), _ctx))

        def begin_getNdFilter(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getNdFilter.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getNdFilter(self, _r):
            return _M_omero.model.LogicalChannel._op_getNdFilter.end(self, _r)

        def setNdFilter(self, theNdFilter, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setNdFilter.invoke(self, ((theNdFilter, ), _ctx))

        def begin_setNdFilter(self, theNdFilter, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setNdFilter.begin(self, ((theNdFilter, ), _response, _ex, _sent, _ctx))

        def end_setNdFilter(self, _r):
            return _M_omero.model.LogicalChannel._op_setNdFilter.end(self, _r)

        def getOtf(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getOtf.invoke(self, ((), _ctx))

        def begin_getOtf(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getOtf.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getOtf(self, _r):
            return _M_omero.model.LogicalChannel._op_getOtf.end(self, _r)

        def setOtf(self, theOtf, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setOtf.invoke(self, ((theOtf, ), _ctx))

        def begin_setOtf(self, theOtf, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setOtf.begin(self, ((theOtf, ), _response, _ex, _sent, _ctx))

        def end_setOtf(self, _r):
            return _M_omero.model.LogicalChannel._op_setOtf.end(self, _r)

        def getDetectorSettings(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getDetectorSettings.invoke(self, ((), _ctx))

        def begin_getDetectorSettings(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getDetectorSettings.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDetectorSettings(self, _r):
            return _M_omero.model.LogicalChannel._op_getDetectorSettings.end(self, _r)

        def setDetectorSettings(self, theDetectorSettings, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setDetectorSettings.invoke(self, ((theDetectorSettings, ), _ctx))

        def begin_setDetectorSettings(self, theDetectorSettings, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setDetectorSettings.begin(self, ((theDetectorSettings, ), _response, _ex, _sent, _ctx))

        def end_setDetectorSettings(self, _r):
            return _M_omero.model.LogicalChannel._op_setDetectorSettings.end(self, _r)

        def getLightSourceSettings(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getLightSourceSettings.invoke(self, ((), _ctx))

        def begin_getLightSourceSettings(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getLightSourceSettings.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getLightSourceSettings(self, _r):
            return _M_omero.model.LogicalChannel._op_getLightSourceSettings.end(self, _r)

        def setLightSourceSettings(self, theLightSourceSettings, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setLightSourceSettings.invoke(self, ((theLightSourceSettings, ), _ctx))

        def begin_setLightSourceSettings(self, theLightSourceSettings, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setLightSourceSettings.begin(self, ((theLightSourceSettings, ), _response, _ex, _sent, _ctx))

        def end_setLightSourceSettings(self, _r):
            return _M_omero.model.LogicalChannel._op_setLightSourceSettings.end(self, _r)

        def getFilterSet(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getFilterSet.invoke(self, ((), _ctx))

        def begin_getFilterSet(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getFilterSet.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getFilterSet(self, _r):
            return _M_omero.model.LogicalChannel._op_getFilterSet.end(self, _r)

        def setFilterSet(self, theFilterSet, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setFilterSet.invoke(self, ((theFilterSet, ), _ctx))

        def begin_setFilterSet(self, theFilterSet, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setFilterSet.begin(self, ((theFilterSet, ), _response, _ex, _sent, _ctx))

        def end_setFilterSet(self, _r):
            return _M_omero.model.LogicalChannel._op_setFilterSet.end(self, _r)

        def getSamplesPerPixel(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getSamplesPerPixel.invoke(self, ((), _ctx))

        def begin_getSamplesPerPixel(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getSamplesPerPixel.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getSamplesPerPixel(self, _r):
            return _M_omero.model.LogicalChannel._op_getSamplesPerPixel.end(self, _r)

        def setSamplesPerPixel(self, theSamplesPerPixel, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setSamplesPerPixel.invoke(self, ((theSamplesPerPixel, ), _ctx))

        def begin_setSamplesPerPixel(self, theSamplesPerPixel, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setSamplesPerPixel.begin(self, ((theSamplesPerPixel, ), _response, _ex, _sent, _ctx))

        def end_setSamplesPerPixel(self, _r):
            return _M_omero.model.LogicalChannel._op_setSamplesPerPixel.end(self, _r)

        def getPhotometricInterpretation(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getPhotometricInterpretation.invoke(self, ((), _ctx))

        def begin_getPhotometricInterpretation(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getPhotometricInterpretation.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPhotometricInterpretation(self, _r):
            return _M_omero.model.LogicalChannel._op_getPhotometricInterpretation.end(self, _r)

        def setPhotometricInterpretation(self, thePhotometricInterpretation, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setPhotometricInterpretation.invoke(self, ((thePhotometricInterpretation, ), _ctx))

        def begin_setPhotometricInterpretation(self, thePhotometricInterpretation, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setPhotometricInterpretation.begin(self, ((thePhotometricInterpretation, ), _response, _ex, _sent, _ctx))

        def end_setPhotometricInterpretation(self, _r):
            return _M_omero.model.LogicalChannel._op_setPhotometricInterpretation.end(self, _r)

        def getMode(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getMode.invoke(self, ((), _ctx))

        def begin_getMode(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getMode.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getMode(self, _r):
            return _M_omero.model.LogicalChannel._op_getMode.end(self, _r)

        def setMode(self, theMode, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setMode.invoke(self, ((theMode, ), _ctx))

        def begin_setMode(self, theMode, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setMode.begin(self, ((theMode, ), _response, _ex, _sent, _ctx))

        def end_setMode(self, _r):
            return _M_omero.model.LogicalChannel._op_setMode.end(self, _r)

        def getPockelCellSetting(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getPockelCellSetting.invoke(self, ((), _ctx))

        def begin_getPockelCellSetting(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getPockelCellSetting.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPockelCellSetting(self, _r):
            return _M_omero.model.LogicalChannel._op_getPockelCellSetting.end(self, _r)

        def setPockelCellSetting(self, thePockelCellSetting, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setPockelCellSetting.invoke(self, ((thePockelCellSetting, ), _ctx))

        def begin_setPockelCellSetting(self, thePockelCellSetting, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setPockelCellSetting.begin(self, ((thePockelCellSetting, ), _response, _ex, _sent, _ctx))

        def end_setPockelCellSetting(self, _r):
            return _M_omero.model.LogicalChannel._op_setPockelCellSetting.end(self, _r)

        def unloadChannels(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_unloadChannels.invoke(self, ((), _ctx))

        def begin_unloadChannels(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_unloadChannels.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadChannels(self, _r):
            return _M_omero.model.LogicalChannel._op_unloadChannels.end(self, _r)

        def sizeOfChannels(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_sizeOfChannels.invoke(self, ((), _ctx))

        def begin_sizeOfChannels(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_sizeOfChannels.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfChannels(self, _r):
            return _M_omero.model.LogicalChannel._op_sizeOfChannels.end(self, _r)

        def copyChannels(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_copyChannels.invoke(self, ((), _ctx))

        def begin_copyChannels(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_copyChannels.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyChannels(self, _r):
            return _M_omero.model.LogicalChannel._op_copyChannels.end(self, _r)

        def addChannel(self, target, _ctx=None):
            return _M_omero.model.LogicalChannel._op_addChannel.invoke(self, ((target, ), _ctx))

        def begin_addChannel(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_addChannel.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addChannel(self, _r):
            return _M_omero.model.LogicalChannel._op_addChannel.end(self, _r)

        def addAllChannelSet(self, targets, _ctx=None):
            return _M_omero.model.LogicalChannel._op_addAllChannelSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllChannelSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_addAllChannelSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllChannelSet(self, _r):
            return _M_omero.model.LogicalChannel._op_addAllChannelSet.end(self, _r)

        def removeChannel(self, theTarget, _ctx=None):
            return _M_omero.model.LogicalChannel._op_removeChannel.invoke(self, ((theTarget, ), _ctx))

        def begin_removeChannel(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_removeChannel.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeChannel(self, _r):
            return _M_omero.model.LogicalChannel._op_removeChannel.end(self, _r)

        def removeAllChannelSet(self, targets, _ctx=None):
            return _M_omero.model.LogicalChannel._op_removeAllChannelSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllChannelSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_removeAllChannelSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllChannelSet(self, _r):
            return _M_omero.model.LogicalChannel._op_removeAllChannelSet.end(self, _r)

        def clearChannels(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_clearChannels.invoke(self, ((), _ctx))

        def begin_clearChannels(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_clearChannels.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearChannels(self, _r):
            return _M_omero.model.LogicalChannel._op_clearChannels.end(self, _r)

        def reloadChannels(self, toCopy, _ctx=None):
            return _M_omero.model.LogicalChannel._op_reloadChannels.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadChannels(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_reloadChannels.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadChannels(self, _r):
            return _M_omero.model.LogicalChannel._op_reloadChannels.end(self, _r)

        def getLightPath(self, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getLightPath.invoke(self, ((), _ctx))

        def begin_getLightPath(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_getLightPath.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getLightPath(self, _r):
            return _M_omero.model.LogicalChannel._op_getLightPath.end(self, _r)

        def setLightPath(self, theLightPath, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setLightPath.invoke(self, ((theLightPath, ), _ctx))

        def begin_setLightPath(self, theLightPath, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LogicalChannel._op_setLightPath.begin(self, ((theLightPath, ), _response, _ex, _sent, _ctx))

        def end_setLightPath(self, _r):
            return _M_omero.model.LogicalChannel._op_setLightPath.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.LogicalChannelPrx.ice_checkedCast(proxy, '::omero::model::LogicalChannel', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.LogicalChannelPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::LogicalChannel'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_LogicalChannelPrx = IcePy.defineProxy('::omero::model::LogicalChannel', LogicalChannelPrx)

    _M_omero.model._t_LogicalChannel = IcePy.declareClass('::omero::model::LogicalChannel')

    _M_omero.model._t_LogicalChannel = IcePy.defineClass('::omero::model::LogicalChannel', LogicalChannel, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_name', (), _M_omero._t_RString, False, 0),
        ('_pinHoleSize', (), _M_omero.model._t_Length, False, 0),
        ('_illumination', (), _M_omero.model._t_Illumination, False, 0),
        ('_contrastMethod', (), _M_omero.model._t_ContrastMethod, False, 0),
        ('_excitationWave', (), _M_omero.model._t_Length, False, 0),
        ('_emissionWave', (), _M_omero.model._t_Length, False, 0),
        ('_fluor', (), _M_omero._t_RString, False, 0),
        ('_ndFilter', (), _M_omero._t_RDouble, False, 0),
        ('_otf', (), _M_omero.model._t_OTF, False, 0),
        ('_detectorSettings', (), _M_omero.model._t_DetectorSettings, False, 0),
        ('_lightSourceSettings', (), _M_omero.model._t_LightSettings, False, 0),
        ('_filterSet', (), _M_omero.model._t_FilterSet, False, 0),
        ('_samplesPerPixel', (), _M_omero._t_RInt, False, 0),
        ('_photometricInterpretation', (), _M_omero.model._t_PhotometricInterpretation, False, 0),
        ('_mode', (), _M_omero.model._t_AcquisitionMode, False, 0),
        ('_pockelCellSetting', (), _M_omero._t_RInt, False, 0),
        ('_channelsSeq', (), _M_omero.model._t_LogicalChannelChannelsSeq, False, 0),
        ('_channelsLoaded', (), IcePy._t_bool, False, 0),
        ('_lightPath', (), _M_omero.model._t_LightPath, False, 0)
    ))
    LogicalChannel._ice_type = _M_omero.model._t_LogicalChannel

    LogicalChannel._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    LogicalChannel._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    LogicalChannel._op_getName = IcePy.Operation('getName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    LogicalChannel._op_setName = IcePy.Operation('setName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    LogicalChannel._op_getPinHoleSize = IcePy.Operation('getPinHoleSize', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    LogicalChannel._op_setPinHoleSize = IcePy.Operation('setPinHoleSize', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    LogicalChannel._op_getIllumination = IcePy.Operation('getIllumination', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Illumination, False, 0), ())
    LogicalChannel._op_setIllumination = IcePy.Operation('setIllumination', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Illumination, False, 0),), (), None, ())
    LogicalChannel._op_getContrastMethod = IcePy.Operation('getContrastMethod', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ContrastMethod, False, 0), ())
    LogicalChannel._op_setContrastMethod = IcePy.Operation('setContrastMethod', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ContrastMethod, False, 0),), (), None, ())
    LogicalChannel._op_getExcitationWave = IcePy.Operation('getExcitationWave', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    LogicalChannel._op_setExcitationWave = IcePy.Operation('setExcitationWave', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    LogicalChannel._op_getEmissionWave = IcePy.Operation('getEmissionWave', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    LogicalChannel._op_setEmissionWave = IcePy.Operation('setEmissionWave', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    LogicalChannel._op_getFluor = IcePy.Operation('getFluor', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    LogicalChannel._op_setFluor = IcePy.Operation('setFluor', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    LogicalChannel._op_getNdFilter = IcePy.Operation('getNdFilter', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    LogicalChannel._op_setNdFilter = IcePy.Operation('setNdFilter', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    LogicalChannel._op_getOtf = IcePy.Operation('getOtf', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_OTF, False, 0), ())
    LogicalChannel._op_setOtf = IcePy.Operation('setOtf', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OTF, False, 0),), (), None, ())
    LogicalChannel._op_getDetectorSettings = IcePy.Operation('getDetectorSettings', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_DetectorSettings, False, 0), ())
    LogicalChannel._op_setDetectorSettings = IcePy.Operation('setDetectorSettings', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_DetectorSettings, False, 0),), (), None, ())
    LogicalChannel._op_getLightSourceSettings = IcePy.Operation('getLightSourceSettings', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_LightSettings, False, 0), ())
    LogicalChannel._op_setLightSourceSettings = IcePy.Operation('setLightSourceSettings', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightSettings, False, 0),), (), None, ())
    LogicalChannel._op_getFilterSet = IcePy.Operation('getFilterSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_FilterSet, False, 0), ())
    LogicalChannel._op_setFilterSet = IcePy.Operation('setFilterSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_FilterSet, False, 0),), (), None, ())
    LogicalChannel._op_getSamplesPerPixel = IcePy.Operation('getSamplesPerPixel', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    LogicalChannel._op_setSamplesPerPixel = IcePy.Operation('setSamplesPerPixel', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    LogicalChannel._op_getPhotometricInterpretation = IcePy.Operation('getPhotometricInterpretation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PhotometricInterpretation, False, 0), ())
    LogicalChannel._op_setPhotometricInterpretation = IcePy.Operation('setPhotometricInterpretation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PhotometricInterpretation, False, 0),), (), None, ())
    LogicalChannel._op_getMode = IcePy.Operation('getMode', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_AcquisitionMode, False, 0), ())
    LogicalChannel._op_setMode = IcePy.Operation('setMode', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_AcquisitionMode, False, 0),), (), None, ())
    LogicalChannel._op_getPockelCellSetting = IcePy.Operation('getPockelCellSetting', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    LogicalChannel._op_setPockelCellSetting = IcePy.Operation('setPockelCellSetting', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    LogicalChannel._op_unloadChannels = IcePy.Operation('unloadChannels', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    LogicalChannel._op_sizeOfChannels = IcePy.Operation('sizeOfChannels', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    LogicalChannel._op_copyChannels = IcePy.Operation('copyChannels', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_LogicalChannelChannelsSeq, False, 0), ())
    LogicalChannel._op_addChannel = IcePy.Operation('addChannel', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Channel, False, 0),), (), None, ())
    LogicalChannel._op_addAllChannelSet = IcePy.Operation('addAllChannelSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LogicalChannelChannelsSeq, False, 0),), (), None, ())
    LogicalChannel._op_removeChannel = IcePy.Operation('removeChannel', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Channel, False, 0),), (), None, ())
    LogicalChannel._op_removeAllChannelSet = IcePy.Operation('removeAllChannelSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LogicalChannelChannelsSeq, False, 0),), (), None, ())
    LogicalChannel._op_clearChannels = IcePy.Operation('clearChannels', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    LogicalChannel._op_reloadChannels = IcePy.Operation('reloadChannels', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LogicalChannel, False, 0),), (), None, ())
    LogicalChannel._op_getLightPath = IcePy.Operation('getLightPath', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_LightPath, False, 0), ())
    LogicalChannel._op_setLightPath = IcePy.Operation('setLightPath', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightPath, False, 0),), (), None, ())

    _M_omero.model.LogicalChannel = LogicalChannel
    del LogicalChannel

    _M_omero.model.LogicalChannelPrx = LogicalChannelPrx
    del LogicalChannelPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `PlaneInfo.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Pixels' not in _M_omero.model.__dict__:
    _M_omero.model._t_Pixels = IcePy.declareClass('::omero::model::Pixels')
    _M_omero.model._t_PixelsPrx = IcePy.declareProxy('::omero::model::Pixels')

if 'Time' not in _M_omero.model.__dict__:
    _M_omero.model._t_Time = IcePy.declareClass('::omero::model::Time')
    _M_omero.model._t_TimePrx = IcePy.declareProxy('::omero::model::Time')

if 'Length' not in _M_omero.model.__dict__:
    _M_omero.model._t_Length = IcePy.declareClass('::omero::model::Length')
    _M_omero.model._t_LengthPrx = IcePy.declareProxy('::omero::model::Length')

if 'PlaneInfoAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_PlaneInfoAnnotationLink = IcePy.declareClass('::omero::model::PlaneInfoAnnotationLink')
    _M_omero.model._t_PlaneInfoAnnotationLinkPrx = IcePy.declareProxy('::omero::model::PlaneInfoAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_PlaneInfoAnnotationLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_PlaneInfoAnnotationLinksSeq = IcePy.defineSequence('::omero::model::PlaneInfoAnnotationLinksSeq', (), _M_omero.model._t_PlaneInfoAnnotationLink)

if '_t_PlaneInfoLinkedAnnotationSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_PlaneInfoLinkedAnnotationSeq = IcePy.defineSequence('::omero::model::PlaneInfoLinkedAnnotationSeq', (), _M_omero.model._t_Annotation)

if 'PlaneInfo' not in _M_omero.model.__dict__:
    _M_omero.model.PlaneInfo = Ice.createTempClass()
    class PlaneInfo(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _pixels=None, _theZ=None, _theC=None, _theT=None, _deltaT=None, _positionX=None, _positionY=None, _positionZ=None, _exposureTime=None, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None):
            if Ice.getType(self) == _M_omero.model.PlaneInfo:
                raise RuntimeError('omero.model.PlaneInfo is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._pixels = _pixels
            self._theZ = _theZ
            self._theC = _theC
            self._theT = _theT
            self._deltaT = _deltaT
            self._positionX = _positionX
            self._positionY = _positionY
            self._positionZ = _positionZ
            self._exposureTime = _exposureTime
            self._annotationLinksSeq = _annotationLinksSeq
            self._annotationLinksLoaded = _annotationLinksLoaded
            self._annotationLinksCountPerOwner = _annotationLinksCountPerOwner

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::PlaneInfo')

        def ice_id(self, current=None):
            return '::omero::model::PlaneInfo'

        def ice_staticId():
            return '::omero::model::PlaneInfo'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getPixels(self, current=None):
            pass

        def setPixels(self, thePixels, current=None):
            pass

        def getTheZ(self, current=None):
            pass

        def setTheZ(self, theTheZ, current=None):
            pass

        def getTheC(self, current=None):
            pass

        def setTheC(self, theTheC, current=None):
            pass

        def getTheT(self, current=None):
            pass

        def setTheT(self, theTheT, current=None):
            pass

        def getDeltaT(self, current=None):
            pass

        def setDeltaT(self, theDeltaT, current=None):
            pass

        def getPositionX(self, current=None):
            pass

        def setPositionX(self, thePositionX, current=None):
            pass

        def getPositionY(self, current=None):
            pass

        def setPositionY(self, thePositionY, current=None):
            pass

        def getPositionZ(self, current=None):
            pass

        def setPositionZ(self, thePositionZ, current=None):
            pass

        def getExposureTime(self, current=None):
            pass

        def setExposureTime(self, theExposureTime, current=None):
            pass

        def unloadAnnotationLinks(self, current=None):
            pass

        def sizeOfAnnotationLinks(self, current=None):
            pass

        def copyAnnotationLinks(self, current=None):
            pass

        def addPlaneInfoAnnotationLink(self, target, current=None):
            pass

        def addAllPlaneInfoAnnotationLinkSet(self, targets, current=None):
            pass

        def removePlaneInfoAnnotationLink(self, theTarget, current=None):
            pass

        def removeAllPlaneInfoAnnotationLinkSet(self, targets, current=None):
            pass

        def clearAnnotationLinks(self, current=None):
            pass

        def reloadAnnotationLinks(self, toCopy, current=None):
            pass

        def getAnnotationLinksCountPerOwner(self, current=None):
            pass

        def linkAnnotation(self, addition, current=None):
            pass

        def addPlaneInfoAnnotationLinkToBoth(self, link, bothSides, current=None):
            pass

        def findPlaneInfoAnnotationLink(self, removal, current=None):
            pass

        def unlinkAnnotation(self, removal, current=None):
            pass

        def removePlaneInfoAnnotationLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedAnnotationList(self, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_PlaneInfo)

        __repr__ = __str__

    _M_omero.model.PlaneInfoPrx = Ice.createTempClass()
    class PlaneInfoPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.PlaneInfo._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.PlaneInfo._op_setVersion.end(self, _r)

        def getPixels(self, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getPixels.invoke(self, ((), _ctx))

        def begin_getPixels(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getPixels.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPixels(self, _r):
            return _M_omero.model.PlaneInfo._op_getPixels.end(self, _r)

        def setPixels(self, thePixels, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setPixels.invoke(self, ((thePixels, ), _ctx))

        def begin_setPixels(self, thePixels, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setPixels.begin(self, ((thePixels, ), _response, _ex, _sent, _ctx))

        def end_setPixels(self, _r):
            return _M_omero.model.PlaneInfo._op_setPixels.end(self, _r)

        def getTheZ(self, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getTheZ.invoke(self, ((), _ctx))

        def begin_getTheZ(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getTheZ.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getTheZ(self, _r):
            return _M_omero.model.PlaneInfo._op_getTheZ.end(self, _r)

        def setTheZ(self, theTheZ, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setTheZ.invoke(self, ((theTheZ, ), _ctx))

        def begin_setTheZ(self, theTheZ, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setTheZ.begin(self, ((theTheZ, ), _response, _ex, _sent, _ctx))

        def end_setTheZ(self, _r):
            return _M_omero.model.PlaneInfo._op_setTheZ.end(self, _r)

        def getTheC(self, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getTheC.invoke(self, ((), _ctx))

        def begin_getTheC(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getTheC.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getTheC(self, _r):
            return _M_omero.model.PlaneInfo._op_getTheC.end(self, _r)

        def setTheC(self, theTheC, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setTheC.invoke(self, ((theTheC, ), _ctx))

        def begin_setTheC(self, theTheC, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setTheC.begin(self, ((theTheC, ), _response, _ex, _sent, _ctx))

        def end_setTheC(self, _r):
            return _M_omero.model.PlaneInfo._op_setTheC.end(self, _r)

        def getTheT(self, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getTheT.invoke(self, ((), _ctx))

        def begin_getTheT(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getTheT.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getTheT(self, _r):
            return _M_omero.model.PlaneInfo._op_getTheT.end(self, _r)

        def setTheT(self, theTheT, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setTheT.invoke(self, ((theTheT, ), _ctx))

        def begin_setTheT(self, theTheT, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setTheT.begin(self, ((theTheT, ), _response, _ex, _sent, _ctx))

        def end_setTheT(self, _r):
            return _M_omero.model.PlaneInfo._op_setTheT.end(self, _r)

        def getDeltaT(self, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getDeltaT.invoke(self, ((), _ctx))

        def begin_getDeltaT(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getDeltaT.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDeltaT(self, _r):
            return _M_omero.model.PlaneInfo._op_getDeltaT.end(self, _r)

        def setDeltaT(self, theDeltaT, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setDeltaT.invoke(self, ((theDeltaT, ), _ctx))

        def begin_setDeltaT(self, theDeltaT, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setDeltaT.begin(self, ((theDeltaT, ), _response, _ex, _sent, _ctx))

        def end_setDeltaT(self, _r):
            return _M_omero.model.PlaneInfo._op_setDeltaT.end(self, _r)

        def getPositionX(self, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getPositionX.invoke(self, ((), _ctx))

        def begin_getPositionX(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getPositionX.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPositionX(self, _r):
            return _M_omero.model.PlaneInfo._op_getPositionX.end(self, _r)

        def setPositionX(self, thePositionX, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setPositionX.invoke(self, ((thePositionX, ), _ctx))

        def begin_setPositionX(self, thePositionX, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setPositionX.begin(self, ((thePositionX, ), _response, _ex, _sent, _ctx))

        def end_setPositionX(self, _r):
            return _M_omero.model.PlaneInfo._op_setPositionX.end(self, _r)

        def getPositionY(self, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getPositionY.invoke(self, ((), _ctx))

        def begin_getPositionY(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getPositionY.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPositionY(self, _r):
            return _M_omero.model.PlaneInfo._op_getPositionY.end(self, _r)

        def setPositionY(self, thePositionY, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setPositionY.invoke(self, ((thePositionY, ), _ctx))

        def begin_setPositionY(self, thePositionY, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setPositionY.begin(self, ((thePositionY, ), _response, _ex, _sent, _ctx))

        def end_setPositionY(self, _r):
            return _M_omero.model.PlaneInfo._op_setPositionY.end(self, _r)

        def getPositionZ(self, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getPositionZ.invoke(self, ((), _ctx))

        def begin_getPositionZ(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getPositionZ.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPositionZ(self, _r):
            return _M_omero.model.PlaneInfo._op_getPositionZ.end(self, _r)

        def setPositionZ(self, thePositionZ, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setPositionZ.invoke(self, ((thePositionZ, ), _ctx))

        def begin_setPositionZ(self, thePositionZ, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setPositionZ.begin(self, ((thePositionZ, ), _response, _ex, _sent, _ctx))

        def end_setPositionZ(self, _r):
            return _M_omero.model.PlaneInfo._op_setPositionZ.end(self, _r)

        def getExposureTime(self, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getExposureTime.invoke(self, ((), _ctx))

        def begin_getExposureTime(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getExposureTime.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getExposureTime(self, _r):
            return _M_omero.model.PlaneInfo._op_getExposureTime.end(self, _r)

        def setExposureTime(self, theExposureTime, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setExposureTime.invoke(self, ((theExposureTime, ), _ctx))

        def begin_setExposureTime(self, theExposureTime, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_setExposureTime.begin(self, ((theExposureTime, ), _response, _ex, _sent, _ctx))

        def end_setExposureTime(self, _r):
            return _M_omero.model.PlaneInfo._op_setExposureTime.end(self, _r)

        def unloadAnnotationLinks(self, _ctx=None):
            return _M_omero.model.PlaneInfo._op_unloadAnnotationLinks.invoke(self, ((), _ctx))

        def begin_unloadAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_unloadAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadAnnotationLinks(self, _r):
            return _M_omero.model.PlaneInfo._op_unloadAnnotationLinks.end(self, _r)

        def sizeOfAnnotationLinks(self, _ctx=None):
            return _M_omero.model.PlaneInfo._op_sizeOfAnnotationLinks.invoke(self, ((), _ctx))

        def begin_sizeOfAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_sizeOfAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfAnnotationLinks(self, _r):
            return _M_omero.model.PlaneInfo._op_sizeOfAnnotationLinks.end(self, _r)

        def copyAnnotationLinks(self, _ctx=None):
            return _M_omero.model.PlaneInfo._op_copyAnnotationLinks.invoke(self, ((), _ctx))

        def begin_copyAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_copyAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyAnnotationLinks(self, _r):
            return _M_omero.model.PlaneInfo._op_copyAnnotationLinks.end(self, _r)

        def addPlaneInfoAnnotationLink(self, target, _ctx=None):
            return _M_omero.model.PlaneInfo._op_addPlaneInfoAnnotationLink.invoke(self, ((target, ), _ctx))

        def begin_addPlaneInfoAnnotationLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_addPlaneInfoAnnotationLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addPlaneInfoAnnotationLink(self, _r):
            return _M_omero.model.PlaneInfo._op_addPlaneInfoAnnotationLink.end(self, _r)

        def addAllPlaneInfoAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.PlaneInfo._op_addAllPlaneInfoAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllPlaneInfoAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_addAllPlaneInfoAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllPlaneInfoAnnotationLinkSet(self, _r):
            return _M_omero.model.PlaneInfo._op_addAllPlaneInfoAnnotationLinkSet.end(self, _r)

        def removePlaneInfoAnnotationLink(self, theTarget, _ctx=None):
            return _M_omero.model.PlaneInfo._op_removePlaneInfoAnnotationLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removePlaneInfoAnnotationLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_removePlaneInfoAnnotationLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removePlaneInfoAnnotationLink(self, _r):
            return _M_omero.model.PlaneInfo._op_removePlaneInfoAnnotationLink.end(self, _r)

        def removeAllPlaneInfoAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.PlaneInfo._op_removeAllPlaneInfoAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllPlaneInfoAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_removeAllPlaneInfoAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllPlaneInfoAnnotationLinkSet(self, _r):
            return _M_omero.model.PlaneInfo._op_removeAllPlaneInfoAnnotationLinkSet.end(self, _r)

        def clearAnnotationLinks(self, _ctx=None):
            return _M_omero.model.PlaneInfo._op_clearAnnotationLinks.invoke(self, ((), _ctx))

        def begin_clearAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_clearAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearAnnotationLinks(self, _r):
            return _M_omero.model.PlaneInfo._op_clearAnnotationLinks.end(self, _r)

        def reloadAnnotationLinks(self, toCopy, _ctx=None):
            return _M_omero.model.PlaneInfo._op_reloadAnnotationLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadAnnotationLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_reloadAnnotationLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadAnnotationLinks(self, _r):
            return _M_omero.model.PlaneInfo._op_reloadAnnotationLinks.end(self, _r)

        def getAnnotationLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getAnnotationLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getAnnotationLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_getAnnotationLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAnnotationLinksCountPerOwner(self, _r):
            return _M_omero.model.PlaneInfo._op_getAnnotationLinksCountPerOwner.end(self, _r)

        def linkAnnotation(self, addition, _ctx=None):
            return _M_omero.model.PlaneInfo._op_linkAnnotation.invoke(self, ((addition, ), _ctx))

        def begin_linkAnnotation(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_linkAnnotation.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkAnnotation(self, _r):
            return _M_omero.model.PlaneInfo._op_linkAnnotation.end(self, _r)

        def addPlaneInfoAnnotationLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.PlaneInfo._op_addPlaneInfoAnnotationLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addPlaneInfoAnnotationLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_addPlaneInfoAnnotationLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addPlaneInfoAnnotationLinkToBoth(self, _r):
            return _M_omero.model.PlaneInfo._op_addPlaneInfoAnnotationLinkToBoth.end(self, _r)

        def findPlaneInfoAnnotationLink(self, removal, _ctx=None):
            return _M_omero.model.PlaneInfo._op_findPlaneInfoAnnotationLink.invoke(self, ((removal, ), _ctx))

        def begin_findPlaneInfoAnnotationLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_findPlaneInfoAnnotationLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findPlaneInfoAnnotationLink(self, _r):
            return _M_omero.model.PlaneInfo._op_findPlaneInfoAnnotationLink.end(self, _r)

        def unlinkAnnotation(self, removal, _ctx=None):
            return _M_omero.model.PlaneInfo._op_unlinkAnnotation.invoke(self, ((removal, ), _ctx))

        def begin_unlinkAnnotation(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_unlinkAnnotation.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkAnnotation(self, _r):
            return _M_omero.model.PlaneInfo._op_unlinkAnnotation.end(self, _r)

        def removePlaneInfoAnnotationLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.PlaneInfo._op_removePlaneInfoAnnotationLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removePlaneInfoAnnotationLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_removePlaneInfoAnnotationLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removePlaneInfoAnnotationLinkFromBoth(self, _r):
            return _M_omero.model.PlaneInfo._op_removePlaneInfoAnnotationLinkFromBoth.end(self, _r)

        def linkedAnnotationList(self, _ctx=None):
            return _M_omero.model.PlaneInfo._op_linkedAnnotationList.invoke(self, ((), _ctx))

        def begin_linkedAnnotationList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneInfo._op_linkedAnnotationList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedAnnotationList(self, _r):
            return _M_omero.model.PlaneInfo._op_linkedAnnotationList.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.PlaneInfoPrx.ice_checkedCast(proxy, '::omero::model::PlaneInfo', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.PlaneInfoPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::PlaneInfo'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_PlaneInfoPrx = IcePy.defineProxy('::omero::model::PlaneInfo', PlaneInfoPrx)

    _M_omero.model._t_PlaneInfo = IcePy.declareClass('::omero::model::PlaneInfo')

    _M_omero.model._t_PlaneInfo = IcePy.defineClass('::omero::model::PlaneInfo', PlaneInfo, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_pixels', (), _M_omero.model._t_Pixels, False, 0),
        ('_theZ', (), _M_omero._t_RInt, False, 0),
        ('_theC', (), _M_omero._t_RInt, False, 0),
        ('_theT', (), _M_omero._t_RInt, False, 0),
        ('_deltaT', (), _M_omero.model._t_Time, False, 0),
        ('_positionX', (), _M_omero.model._t_Length, False, 0),
        ('_positionY', (), _M_omero.model._t_Length, False, 0),
        ('_positionZ', (), _M_omero.model._t_Length, False, 0),
        ('_exposureTime', (), _M_omero.model._t_Time, False, 0),
        ('_annotationLinksSeq', (), _M_omero.model._t_PlaneInfoAnnotationLinksSeq, False, 0),
        ('_annotationLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_annotationLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0)
    ))
    PlaneInfo._ice_type = _M_omero.model._t_PlaneInfo

    PlaneInfo._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    PlaneInfo._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    PlaneInfo._op_getPixels = IcePy.Operation('getPixels', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Pixels, False, 0), ())
    PlaneInfo._op_setPixels = IcePy.Operation('setPixels', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Pixels, False, 0),), (), None, ())
    PlaneInfo._op_getTheZ = IcePy.Operation('getTheZ', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    PlaneInfo._op_setTheZ = IcePy.Operation('setTheZ', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    PlaneInfo._op_getTheC = IcePy.Operation('getTheC', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    PlaneInfo._op_setTheC = IcePy.Operation('setTheC', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    PlaneInfo._op_getTheT = IcePy.Operation('getTheT', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    PlaneInfo._op_setTheT = IcePy.Operation('setTheT', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    PlaneInfo._op_getDeltaT = IcePy.Operation('getDeltaT', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Time, False, 0), ())
    PlaneInfo._op_setDeltaT = IcePy.Operation('setDeltaT', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Time, False, 0),), (), None, ())
    PlaneInfo._op_getPositionX = IcePy.Operation('getPositionX', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    PlaneInfo._op_setPositionX = IcePy.Operation('setPositionX', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    PlaneInfo._op_getPositionY = IcePy.Operation('getPositionY', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    PlaneInfo._op_setPositionY = IcePy.Operation('setPositionY', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    PlaneInfo._op_getPositionZ = IcePy.Operation('getPositionZ', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    PlaneInfo._op_setPositionZ = IcePy.Operation('setPositionZ', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    PlaneInfo._op_getExposureTime = IcePy.Operation('getExposureTime', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Time, False, 0), ())
    PlaneInfo._op_setExposureTime = IcePy.Operation('setExposureTime', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Time, False, 0),), (), None, ())
    PlaneInfo._op_unloadAnnotationLinks = IcePy.Operation('unloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    PlaneInfo._op_sizeOfAnnotationLinks = IcePy.Operation('sizeOfAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    PlaneInfo._op_copyAnnotationLinks = IcePy.Operation('copyAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PlaneInfoAnnotationLinksSeq, False, 0), ())
    PlaneInfo._op_addPlaneInfoAnnotationLink = IcePy.Operation('addPlaneInfoAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlaneInfoAnnotationLink, False, 0),), (), None, ())
    PlaneInfo._op_addAllPlaneInfoAnnotationLinkSet = IcePy.Operation('addAllPlaneInfoAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlaneInfoAnnotationLinksSeq, False, 0),), (), None, ())
    PlaneInfo._op_removePlaneInfoAnnotationLink = IcePy.Operation('removePlaneInfoAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlaneInfoAnnotationLink, False, 0),), (), None, ())
    PlaneInfo._op_removeAllPlaneInfoAnnotationLinkSet = IcePy.Operation('removeAllPlaneInfoAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlaneInfoAnnotationLinksSeq, False, 0),), (), None, ())
    PlaneInfo._op_clearAnnotationLinks = IcePy.Operation('clearAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    PlaneInfo._op_reloadAnnotationLinks = IcePy.Operation('reloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlaneInfo, False, 0),), (), None, ())
    PlaneInfo._op_getAnnotationLinksCountPerOwner = IcePy.Operation('getAnnotationLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    PlaneInfo._op_linkAnnotation = IcePy.Operation('linkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_PlaneInfoAnnotationLink, False, 0), ())
    PlaneInfo._op_addPlaneInfoAnnotationLinkToBoth = IcePy.Operation('addPlaneInfoAnnotationLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlaneInfoAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    PlaneInfo._op_findPlaneInfoAnnotationLink = IcePy.Operation('findPlaneInfoAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_PlaneInfoAnnotationLinksSeq, False, 0), ())
    PlaneInfo._op_unlinkAnnotation = IcePy.Operation('unlinkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), None, ())
    PlaneInfo._op_removePlaneInfoAnnotationLinkFromBoth = IcePy.Operation('removePlaneInfoAnnotationLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlaneInfoAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    PlaneInfo._op_linkedAnnotationList = IcePy.Operation('linkedAnnotationList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PlaneInfoLinkedAnnotationSeq, False, 0), ())

    _M_omero.model.PlaneInfo = PlaneInfo
    del PlaneInfo

    _M_omero.model.PlaneInfoPrx = PlaneInfoPrx
    del PlaneInfoPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# 
# Copyright 2009-2014 Glencoe Software, Inc. All rights reserved.
# Use is subject to license terms supplied in LICENSE.txt
"""
   User administration plugin
"""

import sys

from omero.cli import UserGroupControl, CLI, ExceptionHandler, admin_only
from omero.model.enums import (AdminPrivilegeModifyGroupMembership,
                               AdminPrivilegeModifyUser)
from omero.rtypes import unwrap as _

HELP = "Support for adding and managing users"


class UserControl(UserGroupControl):

    def _configure(self, parser):

        self.exc = ExceptionHandler()

        parser.add_login_arguments()
        sub = parser.sub()

        add = parser.add(sub, self.add, help="Add user")
        add.add_argument(
            "--ignore-existing", action="store_true", default=False,
            help="Do not fail if user already exists")
        add.add_argument(
            "-m", "--middlename", help="Middle name, if available")
        add.add_argument("-e", "--email")
        add.add_argument("-i", "--institution")
        # Capitalized since conflict with main values
        add.add_argument(
            "-a", "--admin", action="store_true",
            help="Whether the user should be an admin")
        add.add_argument("username", help="User's login name")
        add.add_argument("firstname", help="User's first name")
        add.add_argument("lastname", help="User's last name")
        self.add_group_arguments(add, " to join")

        password_group = add.add_mutually_exclusive_group()
        password_group.add_argument(
            "-P", "--userpassword", help="Password for user")
        password_group.add_argument(
            "--no-password", action="store_true", default=False,
            help="Create user with empty password")

        list = parser.add(
            sub, self.list, help="List information about all users")

        info = parser.add(
            sub, self.info,
            "List information about the user(s). Default to the context user")
        self.add_user_arguments(info)

        for x in (list, info):
            x.add_style_argument()
            x.add_group_print_arguments()
            x.add_user_sorting_arguments()

        listgroups = parser.add(
            sub, self.listgroups,
            "List the groups of the user. Default to the context user")
        self.add_user_arguments(listgroups)
        listgroups.add_style_argument()
        listgroups.add_user_print_arguments()
        listgroups.add_group_sorting_arguments()

        password = parser.add(
            sub, self.password, help="Set user's password")
        password.add_argument(
            "username", nargs="?", help="Username if not the current user")

        email = parser.add(
            sub, self.email, help="List users' email addresses")
        email.add_argument(
            "-n", "--names", action="store_true", default=False,
            help="Print user names along with email addresses")
        email.add_argument(
            "-1", "--one", action="store_true", default=False,
            help="Print one user per line")
        email.add_argument(
            "-i", "--ignore", action="store_true", default=False,
            help="Ignore users without email addresses")
        email.add_argument(
            "--all", action="store_true", default=False,
            help="Include all users, including deactivated accounts")

        joingroup = parser.add(sub, self.joingroup, "Join one or more groups")
        self.add_id_name_arguments(
            joingroup, "user. Default to the current user")
        group = self.add_group_arguments(joingroup, " to join")
        group.add_argument(
            "--as-owner", action="store_true", default=False,
            help="Join the group(s) as an owner")

        leavegroup = parser.add(
            sub, self.leavegroup, "Leave one or more groups")
        self.add_id_name_arguments(
            leavegroup, "user. Default to the current user")
        group = self.add_group_arguments(leavegroup, " to leave")
        group.add_argument(
            "--as-owner", action="store_true", default=False,
            help="Leave the owner list of the group(s)")

        for x in (email, password, list, add, joingroup, leavegroup):
            x.add_login_arguments()

    def format_name(self, exp):
        record = ""
        fn = _(exp.firstName)
        mn = " "
        if _(exp.middleName):
            mn = " %s " % _(exp.middleName)
        ln = _(exp.lastName)
        record += "%s%s%s" % (fn, mn, ln)
        return record

    def email(self, args):
        c = self.ctx.conn(args)
        a = c.sf.getAdminService()
        r = a.getSecurityRoles()

        skipped = []
        records = []
        for exp in a.lookupExperimenters():

            # Handle users without email
            if not _(exp.email):
                if not args.ignore:
                    skipped.append(exp)
                continue

            # Handle deactivated users
            if not args.all:
                groups = exp.linkedExperimenterGroupList()
                group_ids = [x.id.val for x in groups]
                if r.userGroupId not in group_ids:
                    continue

            record = ""
            if args.names:
                record += '"%s"' % self.format_name(exp)
                record += " <%s>" % _(exp.email)
            else:
                record += _(exp.email)

            records.append(record)

        if args.one:
            for record in records:
                self.ctx.out(record)
        else:
            self.ctx.out(", ".join(records))

        if skipped:
            self.ctx.err("Missing email addresses:")
            for s in skipped:
                self.ctx.err(self.format_name(s))

    def password(self, args):
        import omero
        from omero.rtypes import rstring
        client = self.ctx.conn(args)
        own_name = self.ctx.get_event_context().userName
        admin = client.sf.getAdminService()

        # tickets 3202, 5841
        own_pw = self._ask_for_password(" for your user (%s)"
                                        % own_name, strict=False)
        try:
            client.sf.setSecurityPassword(own_pw)
            self.ctx.out("Verified password.\n")
        except omero.SecurityViolation as sv:
            import traceback
            self.ctx.die(456, "SecurityViolation: Bad credentials")
            self.ctx.dbg(traceback.format_exception(None, e, sys.exc_info()[2]))

        if args.username:
            try:
                e = admin.lookupExperimenter(args.username)
            except omero.ApiUsageException:
                self.ctx.die(457, "Unknown user: %s" % args.username)
                return  # Never reached
            self.ctx.out("Changing password for %s (id:%s)" % (
                args.username, e.id.val))
        else:
            self.ctx.out("Changing password for %s" % own_name)

        pw = self._ask_for_password(" to be set")
        pw = rstring(pw)
        if args.username:
            admin.changeUserPassword(args.username, pw)
        else:
            admin.changePassword(pw)
        self.ctx.out("Password changed")

    def list(self, args):
        c = self.ctx.conn(args)
        a = c.sf.getAdminService()
        users = a.lookupExperimenters()
        self.output_users_list(a, users, args)

    def info(self, args):
        c = self.ctx.conn(args)
        a = c.sf.getAdminService()
        [uids, users] = self.list_users(a, args, use_context=True)
        self.output_users_list(a, users, args)

    def listgroups(self, args):
        c = self.ctx.conn(args)
        admin = c.sf.getAdminService()
        [uids, groups] = self.list_users(admin, args, use_context=True)
        if len(uids) != 1:
            self.ctx.die(516, 'Too many user arguments')
        groups = admin.containedGroups(uids[0])
        self.output_groups_list(groups, args)

    @admin_only(AdminPrivilegeModifyUser, AdminPrivilegeModifyGroupMembership)
    def add(self, args):
        email = args.email
        login = args.username
        first = args.firstname
        middle = args.middlename
        last = args.lastname
        inst = args.institution
        pasw = args.userpassword

        import omero
        from omero.rtypes import rbool, rstring
        from omero_model_ExperimenterI import ExperimenterI as Exp
        from omero_model_ExperimenterGroupI import ExperimenterGroupI as Grp
        c = self.ctx.conn(args)
        e = Exp()
        e.omeName = rstring(login)
        e.firstName = rstring(first)
        e.lastName = rstring(last)
        e.middleName = rstring(middle)
        e.email = rstring(email)
        e.institution = rstring(inst)
        e.ldap = rbool(False)

        # Fail-fast if no-password is passed and the server does not accept
        # empty passwords
        configService = c.getSession().getConfigService()
        password_required = configService.getConfigValue(
            "omero.security.password_required").lower()
        if args.no_password and password_required != 'false':
            self.ctx.die(502, "Server does not allow user creation with empty"
                         " passwords")

        # Check user existence
        admin = c.getSession().getAdminService()
        try:
            usr = admin.lookupExperimenter(login)
            if usr:
                if args.ignore_existing:
                    self.ctx.out("User exists: %s (id=%s)"
                                 % (login, usr.id.val))
                    return
                else:
                    self.ctx.die(3, "User exists: %s (id=%s)"
                                 % (login, usr.id.val))
        except omero.ApiUsageException:
            pass  # Apparently no such user exists

        [gid, groups] = self.list_groups(admin, args, use_context=False)

        roles = admin.getSecurityRoles()
        groups.append(Grp(roles.userGroupId, False))
        if args.admin:
            groups.append(Grp(roles.systemGroupId, False))

        group = groups.pop(0)

        try:
            if args.no_password:
                id = admin.createExperimenter(e, group, groups)
                self.ctx.out("Added user %s (id=%s) without password"
                             % (login, id))
            else:
                if pasw is None:
                    pasw = self._ask_for_password(" for your new user (%s)"
                                                  % login, strict=True)
                id = admin.createExperimenterWithPassword(e, rstring(pasw),
                                                          group, groups)
                self.ctx.out("Added user %s (id=%s) with password"
                             % (login, id))
        except omero.ValidationException as ve:
            # Possible, though unlikely after previous check
            if self.exc.is_constraint_violation(ve):
                self.ctx.die(66, "User already exists: %s" % login)
            else:
                self.ctx.die(67, "Unknown ValidationException: %s"
                             % ve.message)
        except omero.SecurityViolation as se:
            self.ctx.die(68, "Security violation: %s" % se.message)

    def parse_userid(self, a, args):
        if args.id:
            user = getattr(args, "id", None)
            return self.find_user_by_id(a, user, fatal=True)
        elif args.name:
            user = getattr(args, "name", None)
            return self.find_user_by_name(a, user, fatal=True)
        else:
            user = self.ctx.get_event_context().userName
            return self.find_user_by_name(a, user, fatal=True)

    def filter_groups(self, groups, uid, owner=False, join=True):

        for group in list(groups):
            if owner:
                uid_list = self.getownerids(group)
                relation = "owner of"
            else:
                uid_list = self.getuserids(group)
                relation = "in"

            if join:
                if uid in uid_list:
                    self.ctx.out("%s is already %s group %s"
                                 % (uid, relation, group.id.val))
                    groups.remove(group)
            else:
                if uid not in uid_list:
                    self.ctx.out("%s is not %s group %s"
                                 % (uid, relation, group.id.val))
                    groups.remove(group)
        return groups

    def joingroup(self, args):
        c = self.ctx.conn(args)
        a = c.sf.getAdminService()

        uid, username = self.parse_userid(a, args)
        [gid, groups] = self.list_groups(a, args, use_context=False)
        groups = self.filter_groups(groups, uid, args.as_owner, True)

        for group in groups:
            if args.as_owner:
                self.addownersbyid(a, group, [uid])
            else:
                self.addusersbyid(a, group, [uid])

    def leavegroup(self, args):
        c = self.ctx.conn(args)
        a = c.sf.getAdminService()

        uid, username = self.parse_userid(a, args)
        [gid, groups] = self.list_groups(a, args, use_context=False)
        groups = self.filter_groups(groups, uid, args.as_owner, False)

        for group in list(groups):
            if args.as_owner:
                self.removeownersbyid(a, group, [uid])
            else:
                self.removeusersbyid(a, group, [uid])
try:
    register("user", UserControl, HELP)
except NameError:
    if __name__ == "__main__":
        cli = CLI()
        cli.register("user", UserControl, HELP)
        cli.invoke(sys.argv[1:])



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
#   Copyright 2007 Glencoe Software, Inc. All rights reserved.
#   Use is subject to license terms supplied in LICENSE.txt
#

import os
import shlex
import platform
import subprocess


DEFAULT_DEBUG = "-Xrunjdwp:server=y,transport=dt_socket,address=8787,suspend=n"


def check_java(command):
    try:
        p = subprocess.Popen(
            [command[0], "-version"], stdout=subprocess.PIPE,
            stderr=subprocess.PIPE)
        p.communicate()
        rc = p.wait()
        if rc == 0:
            return
    except:
        pass  # Falls through to raise

    raise Exception("Java could not be found. (Executable=%s)" % command[0])


def makeVar(key, env):
    if key in list(os.environ.keys()):
        env[key] = os.environ[key]


def cmd(args,
        java="java",
        xargs=None,
        chdir=None,
        debug=None,
        debug_string=DEFAULT_DEBUG):
    """
    Defines the command to be used by run or popen.
    """
    # Convert strings to an array for appending
    if isinstance(java, str):
        command = [java]
    else:
        command = list(java)

    if isinstance(xargs, str):
        xargs = shlex.split(xargs)

    # Add our logging configuration early
    # so that it can be overwritten by xargs
    command += ["-Dlog4j.configuration=%s" % os.path.join("etc", "log4j.xml")]

    # Preapre arguments
    if xargs is not None:
        command += xargs

    # Prepare debugging
    if debug is None:
        if "DEBUG" in list(os.environ.keys()):
            command += ["-Xdebug", debug_string]
    else:
        if debug:
            command += ["-Xdebug", debug_string]

    # Add JAVA_OPTS at the end. ticket:1439
    if "JAVA_OPTS" in list(os.environ.keys()):
        command += shlex.split(os.environ["JAVA_OPTS"])

    # Do any mandatory configuration very late
    command += ["-Djava.awt.headless=true"]

    # Add the actual arguments now
    command += args

    return command


def run(args,
        use_exec=False,
        java="java",
        xargs=None,
        chdir=None,
        debug=None,
        debug_string=DEFAULT_DEBUG,
        stdout=subprocess.PIPE,
        stderr=subprocess.PIPE):
    """
    Execute a Java process, either via subprocess waiting for the process
    to finish and returning the output or if use_exec is True, via os.execvpe
    with the current environment.

    -X style arguments for the Java process can be set either via the xargs
    argument or if unset, the JAVA_OPTS environment variable will be checked.
    Note: shlex.split() is called on the JAVA_OPTS value and so bash-style
    escaping can be used to protect whitespaces.

    Debugging can more simply be turned on by passing True for the debug
    argument. If more control over the debugging configuration is needed,
    pass debug_string.
    """
    command = cmd(args, java, xargs, chdir, debug, debug_string)
    check_java(command)
    if use_exec:
        env = os.environ
        if chdir:
            os.chdir(chdir)
        if platform.system() == "Windows":
            command = ["\"%s\"" % i for i in command]
            os.execvpe(command[0], command, env)
        else:
            os.execvpe(command[0], command, env)
    else:
        p = popen(args, java, xargs, chdir, debug, debug_string)
        output = p.communicate()[0]
        return output


def popen(args,
          java="java",
          xargs=None,
          chdir=None,
          debug=None,
          debug_string=DEFAULT_DEBUG,
          stdout=subprocess.PIPE,
          stderr=subprocess.PIPE):
    """
    Creates a subprocess.Popen object and returns it. Uses cmd() internally
    to create the Java command to be executed. This is the same logic as
    run(use_exec=False) but the Popen is returned rather than the stdout.
    """
    command = cmd(args, java, xargs, chdir, debug, debug_string)
    check_java(command)
    if not chdir:
        chdir = os.getcwd()
    return subprocess.Popen(command, stdout=stdout, stderr=stderr,
                            cwd=chdir, env=os.environ)



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `DetectorSettings.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'ElectricPotential' not in _M_omero.model.__dict__:
    _M_omero.model._t_ElectricPotential = IcePy.declareClass('::omero::model::ElectricPotential')
    _M_omero.model._t_ElectricPotentialPrx = IcePy.declareProxy('::omero::model::ElectricPotential')

if 'Frequency' not in _M_omero.model.__dict__:
    _M_omero.model._t_Frequency = IcePy.declareClass('::omero::model::Frequency')
    _M_omero.model._t_FrequencyPrx = IcePy.declareProxy('::omero::model::Frequency')

if 'Binning' not in _M_omero.model.__dict__:
    _M_omero.model._t_Binning = IcePy.declareClass('::omero::model::Binning')
    _M_omero.model._t_BinningPrx = IcePy.declareProxy('::omero::model::Binning')

if 'Detector' not in _M_omero.model.__dict__:
    _M_omero.model._t_Detector = IcePy.declareClass('::omero::model::Detector')
    _M_omero.model._t_DetectorPrx = IcePy.declareProxy('::omero::model::Detector')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'DetectorSettings' not in _M_omero.model.__dict__:
    _M_omero.model.DetectorSettings = Ice.createTempClass()
    class DetectorSettings(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _voltage=None, _gain=None, _offsetValue=None, _readOutRate=None, _binning=None, _integration=None, _zoom=None, _detector=None):
            if Ice.getType(self) == _M_omero.model.DetectorSettings:
                raise RuntimeError('omero.model.DetectorSettings is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._voltage = _voltage
            self._gain = _gain
            self._offsetValue = _offsetValue
            self._readOutRate = _readOutRate
            self._binning = _binning
            self._integration = _integration
            self._zoom = _zoom
            self._detector = _detector

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::DetectorSettings', '::omero::model::IObject')

        def ice_id(self, current=None):
            return '::omero::model::DetectorSettings'

        def ice_staticId():
            return '::omero::model::DetectorSettings'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getVoltage(self, current=None):
            pass

        def setVoltage(self, theVoltage, current=None):
            pass

        def getGain(self, current=None):
            pass

        def setGain(self, theGain, current=None):
            pass

        def getOffsetValue(self, current=None):
            pass

        def setOffsetValue(self, theOffsetValue, current=None):
            pass

        def getReadOutRate(self, current=None):
            pass

        def setReadOutRate(self, theReadOutRate, current=None):
            pass

        def getBinning(self, current=None):
            pass

        def setBinning(self, theBinning, current=None):
            pass

        def getIntegration(self, current=None):
            pass

        def setIntegration(self, theIntegration, current=None):
            pass

        def getZoom(self, current=None):
            pass

        def setZoom(self, theZoom, current=None):
            pass

        def getDetector(self, current=None):
            pass

        def setDetector(self, theDetector, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_DetectorSettings)

        __repr__ = __str__

    _M_omero.model.DetectorSettingsPrx = Ice.createTempClass()
    class DetectorSettingsPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.DetectorSettings._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DetectorSettings._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.DetectorSettings._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.DetectorSettings._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DetectorSettings._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.DetectorSettings._op_setVersion.end(self, _r)

        def getVoltage(self, _ctx=None):
            return _M_omero.model.DetectorSettings._op_getVoltage.invoke(self, ((), _ctx))

        def begin_getVoltage(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DetectorSettings._op_getVoltage.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVoltage(self, _r):
            return _M_omero.model.DetectorSettings._op_getVoltage.end(self, _r)

        def setVoltage(self, theVoltage, _ctx=None):
            return _M_omero.model.DetectorSettings._op_setVoltage.invoke(self, ((theVoltage, ), _ctx))

        def begin_setVoltage(self, theVoltage, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DetectorSettings._op_setVoltage.begin(self, ((theVoltage, ), _response, _ex, _sent, _ctx))

        def end_setVoltage(self, _r):
            return _M_omero.model.DetectorSettings._op_setVoltage.end(self, _r)

        def getGain(self, _ctx=None):
            return _M_omero.model.DetectorSettings._op_getGain.invoke(self, ((), _ctx))

        def begin_getGain(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DetectorSettings._op_getGain.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getGain(self, _r):
            return _M_omero.model.DetectorSettings._op_getGain.end(self, _r)

        def setGain(self, theGain, _ctx=None):
            return _M_omero.model.DetectorSettings._op_setGain.invoke(self, ((theGain, ), _ctx))

        def begin_setGain(self, theGain, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DetectorSettings._op_setGain.begin(self, ((theGain, ), _response, _ex, _sent, _ctx))

        def end_setGain(self, _r):
            return _M_omero.model.DetectorSettings._op_setGain.end(self, _r)

        def getOffsetValue(self, _ctx=None):
            return _M_omero.model.DetectorSettings._op_getOffsetValue.invoke(self, ((), _ctx))

        def begin_getOffsetValue(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DetectorSettings._op_getOffsetValue.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getOffsetValue(self, _r):
            return _M_omero.model.DetectorSettings._op_getOffsetValue.end(self, _r)

        def setOffsetValue(self, theOffsetValue, _ctx=None):
            return _M_omero.model.DetectorSettings._op_setOffsetValue.invoke(self, ((theOffsetValue, ), _ctx))

        def begin_setOffsetValue(self, theOffsetValue, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DetectorSettings._op_setOffsetValue.begin(self, ((theOffsetValue, ), _response, _ex, _sent, _ctx))

        def end_setOffsetValue(self, _r):
            return _M_omero.model.DetectorSettings._op_setOffsetValue.end(self, _r)

        def getReadOutRate(self, _ctx=None):
            return _M_omero.model.DetectorSettings._op_getReadOutRate.invoke(self, ((), _ctx))

        def begin_getReadOutRate(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DetectorSettings._op_getReadOutRate.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getReadOutRate(self, _r):
            return _M_omero.model.DetectorSettings._op_getReadOutRate.end(self, _r)

        def setReadOutRate(self, theReadOutRate, _ctx=None):
            return _M_omero.model.DetectorSettings._op_setReadOutRate.invoke(self, ((theReadOutRate, ), _ctx))

        def begin_setReadOutRate(self, theReadOutRate, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DetectorSettings._op_setReadOutRate.begin(self, ((theReadOutRate, ), _response, _ex, _sent, _ctx))

        def end_setReadOutRate(self, _r):
            return _M_omero.model.DetectorSettings._op_setReadOutRate.end(self, _r)

        def getBinning(self, _ctx=None):
            return _M_omero.model.DetectorSettings._op_getBinning.invoke(self, ((), _ctx))

        def begin_getBinning(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DetectorSettings._op_getBinning.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getBinning(self, _r):
            return _M_omero.model.DetectorSettings._op_getBinning.end(self, _r)

        def setBinning(self, theBinning, _ctx=None):
            return _M_omero.model.DetectorSettings._op_setBinning.invoke(self, ((theBinning, ), _ctx))

        def begin_setBinning(self, theBinning, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DetectorSettings._op_setBinning.begin(self, ((theBinning, ), _response, _ex, _sent, _ctx))

        def end_setBinning(self, _r):
            return _M_omero.model.DetectorSettings._op_setBinning.end(self, _r)

        def getIntegration(self, _ctx=None):
            return _M_omero.model.DetectorSettings._op_getIntegration.invoke(self, ((), _ctx))

        def begin_getIntegration(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DetectorSettings._op_getIntegration.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getIntegration(self, _r):
            return _M_omero.model.DetectorSettings._op_getIntegration.end(self, _r)

        def setIntegration(self, theIntegration, _ctx=None):
            return _M_omero.model.DetectorSettings._op_setIntegration.invoke(self, ((theIntegration, ), _ctx))

        def begin_setIntegration(self, theIntegration, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DetectorSettings._op_setIntegration.begin(self, ((theIntegration, ), _response, _ex, _sent, _ctx))

        def end_setIntegration(self, _r):
            return _M_omero.model.DetectorSettings._op_setIntegration.end(self, _r)

        def getZoom(self, _ctx=None):
            return _M_omero.model.DetectorSettings._op_getZoom.invoke(self, ((), _ctx))

        def begin_getZoom(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DetectorSettings._op_getZoom.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getZoom(self, _r):
            return _M_omero.model.DetectorSettings._op_getZoom.end(self, _r)

        def setZoom(self, theZoom, _ctx=None):
            return _M_omero.model.DetectorSettings._op_setZoom.invoke(self, ((theZoom, ), _ctx))

        def begin_setZoom(self, theZoom, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DetectorSettings._op_setZoom.begin(self, ((theZoom, ), _response, _ex, _sent, _ctx))

        def end_setZoom(self, _r):
            return _M_omero.model.DetectorSettings._op_setZoom.end(self, _r)

        def getDetector(self, _ctx=None):
            return _M_omero.model.DetectorSettings._op_getDetector.invoke(self, ((), _ctx))

        def begin_getDetector(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DetectorSettings._op_getDetector.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDetector(self, _r):
            return _M_omero.model.DetectorSettings._op_getDetector.end(self, _r)

        def setDetector(self, theDetector, _ctx=None):
            return _M_omero.model.DetectorSettings._op_setDetector.invoke(self, ((theDetector, ), _ctx))

        def begin_setDetector(self, theDetector, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DetectorSettings._op_setDetector.begin(self, ((theDetector, ), _response, _ex, _sent, _ctx))

        def end_setDetector(self, _r):
            return _M_omero.model.DetectorSettings._op_setDetector.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.DetectorSettingsPrx.ice_checkedCast(proxy, '::omero::model::DetectorSettings', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.DetectorSettingsPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::DetectorSettings'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_DetectorSettingsPrx = IcePy.defineProxy('::omero::model::DetectorSettings', DetectorSettingsPrx)

    _M_omero.model._t_DetectorSettings = IcePy.declareClass('::omero::model::DetectorSettings')

    _M_omero.model._t_DetectorSettings = IcePy.defineClass('::omero::model::DetectorSettings', DetectorSettings, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_voltage', (), _M_omero.model._t_ElectricPotential, False, 0),
        ('_gain', (), _M_omero._t_RDouble, False, 0),
        ('_offsetValue', (), _M_omero._t_RDouble, False, 0),
        ('_readOutRate', (), _M_omero.model._t_Frequency, False, 0),
        ('_binning', (), _M_omero.model._t_Binning, False, 0),
        ('_integration', (), _M_omero._t_RInt, False, 0),
        ('_zoom', (), _M_omero._t_RDouble, False, 0),
        ('_detector', (), _M_omero.model._t_Detector, False, 0)
    ))
    DetectorSettings._ice_type = _M_omero.model._t_DetectorSettings

    DetectorSettings._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    DetectorSettings._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    DetectorSettings._op_getVoltage = IcePy.Operation('getVoltage', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ElectricPotential, False, 0), ())
    DetectorSettings._op_setVoltage = IcePy.Operation('setVoltage', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ElectricPotential, False, 0),), (), None, ())
    DetectorSettings._op_getGain = IcePy.Operation('getGain', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    DetectorSettings._op_setGain = IcePy.Operation('setGain', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    DetectorSettings._op_getOffsetValue = IcePy.Operation('getOffsetValue', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    DetectorSettings._op_setOffsetValue = IcePy.Operation('setOffsetValue', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    DetectorSettings._op_getReadOutRate = IcePy.Operation('getReadOutRate', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Frequency, False, 0), ())
    DetectorSettings._op_setReadOutRate = IcePy.Operation('setReadOutRate', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Frequency, False, 0),), (), None, ())
    DetectorSettings._op_getBinning = IcePy.Operation('getBinning', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Binning, False, 0), ())
    DetectorSettings._op_setBinning = IcePy.Operation('setBinning', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Binning, False, 0),), (), None, ())
    DetectorSettings._op_getIntegration = IcePy.Operation('getIntegration', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    DetectorSettings._op_setIntegration = IcePy.Operation('setIntegration', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    DetectorSettings._op_getZoom = IcePy.Operation('getZoom', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    DetectorSettings._op_setZoom = IcePy.Operation('setZoom', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    DetectorSettings._op_getDetector = IcePy.Operation('getDetector', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Detector, False, 0), ())
    DetectorSettings._op_setDetector = IcePy.Operation('setDetector', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Detector, False, 0),), (), None, ())

    _M_omero.model.DetectorSettings = DetectorSettings
    del DetectorSettings

    _M_omero.model.DetectorSettingsPrx = DetectorSettingsPrx
    del DetectorSettingsPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#
#   Copyright 2010-2014 Glencoe Software, Inc. All rights reserved.
#   Use is subject to license terms supplied in LICENSE.txt
#

# This file is an import-only file providing a mechanism for other files to
# import a range of modules in a controlled way. It could be made to pass
# flake8 but given its simplicity it is being marked as noqa for now.
#
# flake8: noqa

import omero
import IceImport
if omero.__import_style__ is None:
    omero.__import_style__ = "min"

# Internal types
IceImport.load("omero_model_NamedValue_ice")

# New Command API
IceImport.load("omero_cmd_Admin_ice")
IceImport.load("omero_cmd_API_ice")
IceImport.load("omero_cmd_Basic_ice")
IceImport.load("omero_cmd_FS_ice")
IceImport.load("omero_cmd_Graphs_ice")
IceImport.load("omero_cmd_Mail_ice")

# Previous ServiceFactory API
IceImport.load("omero_API_ice")
IceImport.load("omero_ServicesF_ice")
IceImport.load("omero_Constants_ice")

IceImport.load("Glacier2_Router_ice")
import omero.rtypes



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright 2008, 2016 Glencoe Software, Inc. All rights reserved.
# Use is subject to license terms supplied in LICENSE.txt

"""
   Plugin for measuring the performance of an OMERO
   installation.

   Plugin read by omero.cli.Cli during initialization. The method(s)
   defined here will be added to the Cli class for later use.
"""
from __future__ import print_function

import sys
from omero.cli import BaseControl, CLI
from omero_ext.argparse import FileType
import omero.install.perf_test as perf_test

HELP = """Run perf_test files

%s

""" % perf_test.FILE_FORMAT


class PerfControl(BaseControl):

    def _configure(self, parser):
        parser.add_argument(
            "-l", "--list", action="store_true",
            help="List available commands")
        parser.add_argument(
            "file", nargs="*", type=FileType('r'), default=None,
            help="Read from files or standard in")
        parser.set_defaults(func=self.__call__)
        parser.add_login_arguments()

    def __call__(self, args):
        if args.list:
            ops = [x[4:] for x in dir(perf_test.Item) if x.startswith("_op_")]
            ops.sort()
            for op in ops:
                print(op)
        else:
            if not args.file:
                self.ctx.die(167, "No files given. Use '-' for stdin.")
            client = self.ctx.conn(args)
            ctx = perf_test.Context(None, client=client)
            self.ctx.out("Saving performance results to %s" % ctx.dir)
            ctx.add_reporter(perf_test.CsvReporter(ctx.dir))
            # ctx.add_reporter(perf_test.HdfReporter(ctx.dir))
            # ctx.add_reporter(perf_test.PlotReporter())
            handler = perf_test.PerfHandler(ctx)
            perf_test.handle(handler, args.file)

try:
    register("perf", PerfControl, HELP)
except NameError:
    if __name__ == "__main__":
        cli = CLI()
        cli.register("perf", PerfControl, HELP)
        cli.invoke(sys.argv[1:])



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `PlaneSlicingContext.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice
import omero_model_CodomainMapContext_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'ChannelBinding' not in _M_omero.model.__dict__:
    _M_omero.model._t_ChannelBinding = IcePy.declareClass('::omero::model::ChannelBinding')
    _M_omero.model._t_ChannelBindingPrx = IcePy.declareProxy('::omero::model::ChannelBinding')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'PlaneSlicingContext' not in _M_omero.model.__dict__:
    _M_omero.model.PlaneSlicingContext = Ice.createTempClass()
    class PlaneSlicingContext(_M_omero.model.CodomainMapContext):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _channelBinding=None, _upperLimit=None, _lowerLimit=None, _planeSelected=None, _planePrevious=None, _constant=None):
            if Ice.getType(self) == _M_omero.model.PlaneSlicingContext:
                raise RuntimeError('omero.model.PlaneSlicingContext is an abstract class')
            _M_omero.model.CodomainMapContext.__init__(self, _id, _details, _loaded, _version, _channelBinding)
            self._upperLimit = _upperLimit
            self._lowerLimit = _lowerLimit
            self._planeSelected = _planeSelected
            self._planePrevious = _planePrevious
            self._constant = _constant

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::CodomainMapContext', '::omero::model::IObject', '::omero::model::PlaneSlicingContext')

        def ice_id(self, current=None):
            return '::omero::model::PlaneSlicingContext'

        def ice_staticId():
            return '::omero::model::PlaneSlicingContext'
        ice_staticId = staticmethod(ice_staticId)

        def getUpperLimit(self, current=None):
            pass

        def setUpperLimit(self, theUpperLimit, current=None):
            pass

        def getLowerLimit(self, current=None):
            pass

        def setLowerLimit(self, theLowerLimit, current=None):
            pass

        def getPlaneSelected(self, current=None):
            pass

        def setPlaneSelected(self, thePlaneSelected, current=None):
            pass

        def getPlanePrevious(self, current=None):
            pass

        def setPlanePrevious(self, thePlanePrevious, current=None):
            pass

        def getConstant(self, current=None):
            pass

        def setConstant(self, theConstant, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_PlaneSlicingContext)

        __repr__ = __str__

    _M_omero.model.PlaneSlicingContextPrx = Ice.createTempClass()
    class PlaneSlicingContextPrx(_M_omero.model.CodomainMapContextPrx):

        def getUpperLimit(self, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_getUpperLimit.invoke(self, ((), _ctx))

        def begin_getUpperLimit(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_getUpperLimit.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getUpperLimit(self, _r):
            return _M_omero.model.PlaneSlicingContext._op_getUpperLimit.end(self, _r)

        def setUpperLimit(self, theUpperLimit, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_setUpperLimit.invoke(self, ((theUpperLimit, ), _ctx))

        def begin_setUpperLimit(self, theUpperLimit, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_setUpperLimit.begin(self, ((theUpperLimit, ), _response, _ex, _sent, _ctx))

        def end_setUpperLimit(self, _r):
            return _M_omero.model.PlaneSlicingContext._op_setUpperLimit.end(self, _r)

        def getLowerLimit(self, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_getLowerLimit.invoke(self, ((), _ctx))

        def begin_getLowerLimit(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_getLowerLimit.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getLowerLimit(self, _r):
            return _M_omero.model.PlaneSlicingContext._op_getLowerLimit.end(self, _r)

        def setLowerLimit(self, theLowerLimit, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_setLowerLimit.invoke(self, ((theLowerLimit, ), _ctx))

        def begin_setLowerLimit(self, theLowerLimit, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_setLowerLimit.begin(self, ((theLowerLimit, ), _response, _ex, _sent, _ctx))

        def end_setLowerLimit(self, _r):
            return _M_omero.model.PlaneSlicingContext._op_setLowerLimit.end(self, _r)

        def getPlaneSelected(self, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_getPlaneSelected.invoke(self, ((), _ctx))

        def begin_getPlaneSelected(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_getPlaneSelected.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPlaneSelected(self, _r):
            return _M_omero.model.PlaneSlicingContext._op_getPlaneSelected.end(self, _r)

        def setPlaneSelected(self, thePlaneSelected, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_setPlaneSelected.invoke(self, ((thePlaneSelected, ), _ctx))

        def begin_setPlaneSelected(self, thePlaneSelected, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_setPlaneSelected.begin(self, ((thePlaneSelected, ), _response, _ex, _sent, _ctx))

        def end_setPlaneSelected(self, _r):
            return _M_omero.model.PlaneSlicingContext._op_setPlaneSelected.end(self, _r)

        def getPlanePrevious(self, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_getPlanePrevious.invoke(self, ((), _ctx))

        def begin_getPlanePrevious(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_getPlanePrevious.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPlanePrevious(self, _r):
            return _M_omero.model.PlaneSlicingContext._op_getPlanePrevious.end(self, _r)

        def setPlanePrevious(self, thePlanePrevious, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_setPlanePrevious.invoke(self, ((thePlanePrevious, ), _ctx))

        def begin_setPlanePrevious(self, thePlanePrevious, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_setPlanePrevious.begin(self, ((thePlanePrevious, ), _response, _ex, _sent, _ctx))

        def end_setPlanePrevious(self, _r):
            return _M_omero.model.PlaneSlicingContext._op_setPlanePrevious.end(self, _r)

        def getConstant(self, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_getConstant.invoke(self, ((), _ctx))

        def begin_getConstant(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_getConstant.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getConstant(self, _r):
            return _M_omero.model.PlaneSlicingContext._op_getConstant.end(self, _r)

        def setConstant(self, theConstant, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_setConstant.invoke(self, ((theConstant, ), _ctx))

        def begin_setConstant(self, theConstant, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.PlaneSlicingContext._op_setConstant.begin(self, ((theConstant, ), _response, _ex, _sent, _ctx))

        def end_setConstant(self, _r):
            return _M_omero.model.PlaneSlicingContext._op_setConstant.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.PlaneSlicingContextPrx.ice_checkedCast(proxy, '::omero::model::PlaneSlicingContext', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.PlaneSlicingContextPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::PlaneSlicingContext'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_PlaneSlicingContextPrx = IcePy.defineProxy('::omero::model::PlaneSlicingContext', PlaneSlicingContextPrx)

    _M_omero.model._t_PlaneSlicingContext = IcePy.declareClass('::omero::model::PlaneSlicingContext')

    _M_omero.model._t_PlaneSlicingContext = IcePy.defineClass('::omero::model::PlaneSlicingContext', PlaneSlicingContext, -1, (), True, False, _M_omero.model._t_CodomainMapContext, (), (
        ('_upperLimit', (), _M_omero._t_RInt, False, 0),
        ('_lowerLimit', (), _M_omero._t_RInt, False, 0),
        ('_planeSelected', (), _M_omero._t_RInt, False, 0),
        ('_planePrevious', (), _M_omero._t_RInt, False, 0),
        ('_constant', (), _M_omero._t_RBool, False, 0)
    ))
    PlaneSlicingContext._ice_type = _M_omero.model._t_PlaneSlicingContext

    PlaneSlicingContext._op_getUpperLimit = IcePy.Operation('getUpperLimit', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    PlaneSlicingContext._op_setUpperLimit = IcePy.Operation('setUpperLimit', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    PlaneSlicingContext._op_getLowerLimit = IcePy.Operation('getLowerLimit', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    PlaneSlicingContext._op_setLowerLimit = IcePy.Operation('setLowerLimit', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    PlaneSlicingContext._op_getPlaneSelected = IcePy.Operation('getPlaneSelected', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    PlaneSlicingContext._op_setPlaneSelected = IcePy.Operation('setPlaneSelected', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    PlaneSlicingContext._op_getPlanePrevious = IcePy.Operation('getPlanePrevious', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    PlaneSlicingContext._op_setPlanePrevious = IcePy.Operation('setPlanePrevious', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    PlaneSlicingContext._op_getConstant = IcePy.Operation('getConstant', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RBool, False, 0), ())
    PlaneSlicingContext._op_setConstant = IcePy.Operation('setConstant', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RBool, False, 0),), (), None, ())

    _M_omero.model.PlaneSlicingContext = PlaneSlicingContext
    del PlaneSlicingContext

    _M_omero.model.PlaneSlicingContextPrx = PlaneSlicingContextPrx
    del PlaneSlicingContextPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero
